#!/usr/bin/env python

import os
import time

def shellQuote(s):
    return "'" + s.replace("'", "'\\''") + "'"

configPath = './config.py'
binaryPath = 'bs_headless.exe' if os.name == 'nt' else './bs_headless'
if not os.path.exists(binaryPath): binaryPath = './bombsquad' # fallback for testing


# Server settings:
# You can modify values directly here, but a more graceful way to do so is
# to enter your overries in the config.py file which will get exec'ed
# after these defaults are set and can replace any of them.
# This way you don't have to re-edit this file every time the server is updated;
# you can just copy your existing config in.

# Name of our server in the public parties list
partyName = "FFA"

# Language the server will run in.
# At some point I'll fix the game so it shows up in the correct language for
# all clients but currently everyone sees everything in the server's language.
# For the list of available languages, look in data/scripts for all files starting with
# bsLanguage.  The last part of the name is the value here.  For instance, to use
# bsLanguageTurkish.py the value would be "Turkish".
# Note that languages requiring the full set of unicode characters beyond latin or cyrilic
# are not currently supported in the linux or windows builds (currently Chinese, Korean, Persian)
# I will also try to fix that when I can.
language = "English"

# Max devices in the party. Note that this does *NOT* mean max players.
# Each device in the party can have more than one player on it (if they have multiple controllers).
# Also, this currently includes the server so generally make it 1 bigger than you need.
# Max-players is not currently exposed but I'll try to add that soon.
maxPartySize = 6

# Options here are bs.FreeForAllSession and bs.TeamsSession
sessionType = "bs.FreeForAllSession"

# If True, keeps team sizes equal by disallowing joining the largest team (teams mode only)
autoBalanceTeams = True

# Playlist is currently hard-coded as the default teams or free-for-all playlist.
# The easiest way to edit it at the moment is to edit data/scripts/bsUtils.py by hand
# (look for _getDefaultFreeForAllPlaylist() and _getDefaultTeamsPlaylist()).
# I will add an option soon for sharing playlists from any account, making it possible
# to just plug in some ID value here.

# Whether to shuffle the playlist or play its games in designated order
playlistShuffle = True

# Whether to enable telnet access on port 43250
# This allows you to run python commands on the server as it is running.
# BombSquad's telnet server is very simple so you may have to turn off any fancy features
# In your telnet client to get it to work.
# There is no password protection so make sure to only enable this if you're in a fully
# trusted environment, behind a firewall, etc.
enableTelnet = False

# If config.py exists, run it to apply any overrides to this stuff..
if os.path.isfile(configPath):
    execfile(configPath)
    
# Ok, now run bombsquad in a loop, allowing it to shut down and re-launch periodically to clean out
# any memory leaks or other cruft. (also recovers in the case of a crash)
while True:
    cmd = (binaryPath+' -exec "bsUtils.runServer('
           +'maxPartySize='+repr(maxPartySize)+', '
           +'sessionType='+sessionType+', '
           +'partyName='+shellQuote(partyName)+', '
           +'autoBalanceTeams='+repr(autoBalanceTeams)+', '
           +'playlistShuffle='+repr(playlistShuffle)+', '
           +'language='+shellQuote(language)+', '
           +'enableTelnet='+repr(enableTelnet)+', '
           +'softShutdownTime='+repr(60*60*12) # cycle after 12 hours
           +')"')
    print 'Launching server binary: '+cmd
    result = os.system(cmd)
    # bs returns code 56 on explicit user cancel (ctrl-c, etc)
    # hmm this only seems to apply to mac; on linux we get a raw result of '2'; need to investigate
    if (result >> 8) == 56 or result == 2: break;
    print 'BombSquad exited with status '+str(result)+'.\nRelaunching in 5 seconds...'
    time.sleep(5)
        
